﻿Imports Infragistics.Win
Imports Infragistics.Win.IGControls
Imports Infragistics.Win.UltraWinSpellChecker

Public Class Form1
    ' Create the context menu for the richtextbox as well
    ' as the Error object.
    Dim shortcut As New IGContextMenu()
    Dim spellingError As [Error]

    Private Sub Creating_a_Shortcut_Menu_to_Resolve_Spelling_Errors_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ' Set the style of the context menu to look like Microsoft Word 2003.
        Me.shortcut.Style = MenuStyle.Office2003
        ' Set the richtextbox's context menu to be the 
        ' context menu we created earlier.	
        Me.TextBox1.ContextMenu = Me.shortcut
        ' Set the User's Dictionary. If you don't have a
        ' dictionary, then leave out this line, we will test
        ' for a user dictionary later. 
        Me.UltraSpellChecker1.UserDictionary = "C:\custom.dict"
    End Sub

    Private Sub PopulateContextMenu(ByVal [error] As [Error])
        ' Clear all menu items in the context menu.
        Me.shortcut.MenuItems.Clear()

        ' Fill the context menu with the first five spelling
        ' suggestions that WinSpellChecker comes up with.
        Dim i As Integer
        For i = 0 To [error].Suggestions.Count - 1
            If i = 5 Then
                Exit For
            End If
            Dim menuItem As IGMenuItem = New IGMenuItem([error].Suggestions(i).ToString(), _
              New EventHandler(AddressOf menuItem_Click))
            Me.shortcut.MenuItems.Add(menuItem)
        Next i

        ' Add a separator to the context menu.
        Dim barBreak As New IGMenuItem("-")
        Me.shortcut.MenuItems.Add(barBreak)

        ' Add a menu item to the context menu that we will
        ' later use to ignore all occurences of the right-
        ' clicked word.
        Dim ignoreAll As IGMenuItem = New IGMenuItem("Ignore All", _
          New System.EventHandler(AddressOf ignoreAll_Click))
        Me.shortcut.MenuItems.Add(ignoreAll)

        ' Add a menu item to the context menu that we will
        ' later use to add the right-clicked word to the
        ' user's dictionary.
        Dim addToDictionary As New IGMenuItem("Add to Dictionary", _
          New System.EventHandler(AddressOf addToDictionary_Click))
        Me.shortcut.MenuItems.Add(addToDictionary)

        ' If there is no user dictionary, disable the "Add
        ' to Dictionary" menu item.
        If Me.UltraSpellChecker1.UserDictionary = "" Then
            Me.shortcut.MenuItems(Me.shortcut.MenuItems.Count - 1).Enabled = False
        End If

        Dim Cut As New IGMenuItem("Cut", New System.EventHandler(AddressOf CutToolStripMenuItem_Click))
        Me.shortcut.MenuItems.Add(Cut)

        Dim Copy As New IGMenuItem("Copy", New System.EventHandler(AddressOf CopyToolStripMenuItem_Click))
        Me.shortcut.MenuItems.Add(Copy)

        Dim Paste As New IGMenuItem("Paste", New System.EventHandler(AddressOf PasteToolStripMenuItem_Click))
        Me.shortcut.MenuItems.Add(Paste)

        Dim Undo As New IGMenuItem("Undo", New System.EventHandler(AddressOf UndoToolStripMenuItem_Click))
        Me.shortcut.MenuItems.Add(Undo)

    End Sub

    Private Sub TextBox1_MouseDown(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles TextBox1.MouseDown
        If e.Button = System.Windows.Forms.MouseButtons.Right Then
            ' Create a new point for spellingError to use
            ' to get the spelling error at point. The point
            ' will be the mouse coordinates.		
            Dim point As New Point(e.X, e.Y)
            ' Get the spelling error at the mouse's coordinates.
            Me.spellingError = Me.UltraSpellChecker1.GetErrorAtPoint(Me.TextBox1, point)


            ' If there is no spelling error at the designated
            ' coordinates, clear the context menu and cancel.
            If spellingError Is Nothing Then
                Me.ContextMenuStrip1.Show(Me.TextBox1, point)
                Me.shortcut.MenuItems.Clear()
                Return
            Else
                Me.PopulateContextMenu(spellingError)
            End If
        End If

    End Sub

    Private Sub menuItem_Click(ByVal sender As Object, ByVal e As EventArgs)
        Dim menuItem As IGMenuItem = sender
        Dim selectSpellingError As Integer = _
          (Me.spellingError.EndIndex - Me.spellingError.StartIndex) + 1

        ' The Select method takes in two arguments in this override:
        ' the starting index of the selection and the length of the
        ' selection. Once the propert text is selected, it is replaced
        ' with the text of the menu item that the user clicked.
        Me.TextBox1.Select(Me.spellingError.StartIndex, selectSpellingError)
        Me.TextBox1.SelectedText = menuItem.Text
    End Sub

    Private Sub ignoreAll_Click(ByVal sender As Object, ByVal e As EventArgs)
        ' Ignore all occurences of the word that was right-clicked.
        Me.UltraSpellChecker1.IgnoreAll(Me.spellingError.CheckedWord.ToString())
    End Sub

    Private Sub addToDictionary_Click(ByVal sender As Object, ByVal e As EventArgs)
        ' add the word that was right-clicked to the user's dictionary.
        Me.UltraSpellChecker1.AddWordToUserDictionary( _
          Me.spellingError.CheckedWord.ToString())
    End Sub

    Private Sub CutToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CutToolStripMenuItem.Click
        Me.TextBox1.Cut()
    End Sub

    Private Sub CopyToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CopyToolStripMenuItem.Click
        Me.TextBox1.Copy()
    End Sub

    Private Sub PasteToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles PasteToolStripMenuItem.Click
        Me.TextBox1.Paste()
    End Sub

    Private Sub UndoToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles UndoToolStripMenuItem.Click
        Me.TextBox1.Undo()
    End Sub
End Class
